@@ -5,7 +5,7 @@ use 5.022;
 use feature qw /postderef signatures/;
 
 package Vote::Count::Approval;
-$Vote::Count::Approval::VERSION = '0.001'; # TRIAL
+$Vote::Count::Approval::VERSION = '0.004'; # TRIAL
 use Moose::Role;
 
 no warnings 'experimental';
@@ -32,32 +32,4 @@ sub Approval ( $self, $active=undef ) {
   return Vote::Count::RankCount->Rank( \%approval );
 }
 
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Vote::Count::Approval
-
-=head1 VERSION
-
-version 0.001
-
-=head1 AUTHOR
-
-John Karr <brainbuz@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2019 by John Karr.
-
-This is free software, licensed under:
-
-  The GNU General Public License, Version 3, June 2007
-
-=cut
+1;
\ No newline at end of file
